==> zcmds-1.1.1-py2.py3-none-any.whl: zcmds/cmds/common/bindings.json.py <==
{
    "common": [
        "zcmds = zcmds.cmds.common.zcmds:main",
        "audnorm = zcmds.cmds.common.audnorm:main",
        "diskaudit = zcmds.cmds.common.diskaudit:main",
        "obs_organize = zcmds.cmds.common.obs_organize:main",
        "pdf2png = zcmds.cmds.common.pdf2png:main",
        "search_and_replace = zcmds.cmds.common.search_and_replace:main",
        "search_in_files = zcmds.cmds.common.search_in_files:main",
        "sharedir = zcmds.cmds.common.sharedir:main",
        "stereo2mono = zcmds.cmds.common.stereo2mono:main",
        "stripaudio = zcmds.cmds.common.stripaudio:main",
        "vid2gif = zcmds.cmds.common.vid2gif:main",
        "vid2jpg = zcmds.cmds.common.vid2jpg:main",
        "vid2mp3 = zcmds.cmds.common.vid2mp3:main",
        "vid2mp4 = zcmds.cmds.common.vid2mp4:main",
        "vid2webm = zcmds.cmds.common.vid2webm:main",
        "vidclip = zcmds.cmds.common.vidclip:main",
        "viddur = zcmds.cmds.common.viddur:main",
        "vidspeed = zcmds.cmds.common.vidspeed:main",
        "vidvol = zcmds.cmds.common.vidvol:main",
        "vidshrink = zcmds.cmds.common.vidshrink:main"
    ],
    "win32": [
        "cat = zcmds.cmds.win32.cat:main",
        "cp = zcmds.cmds.win32.cp:main",
        "du = zcmds.cmds.win32.du:main",
        "grep = zcmds.cmds.win32.grep:main",
        "home = zcmds.cmds.win32.home:main",
        "ls = zcmds.cmds.win32.ls:main",
        "mv = zcmds.cmds.win32.mv:main",
        "open = zcmds.cmds.win32.open:main",
        "rm = zcmds.cmds.win32.rm:main",
        "which = zcmds.cmds.win32.which:main"
    ]
}

==> zcmds-1.1.4-py2.py3-none-any.whl: zcmds/cmds/common/bindings.json.py <==
{
    "common": [
        "zcmds = zcmds.cmds.common.zcmds:main",
        "audnorm = zcmds.cmds.common.audnorm:main",
        "diskaudit = zcmds.cmds.common.diskaudit:main",
        "obs_organize = zcmds.cmds.common.obs_organize:main",
        "pdf2png = zcmds.cmds.common.pdf2png:main",
        "search_and_replace = zcmds.cmds.common.search_and_replace:main",
        "search_in_files = zcmds.cmds.common.search_in_files:main",
        "sharedir = zcmds.cmds.common.sharedir:main",
        "stereo2mono = zcmds.cmds.common.stereo2mono:main",
        "stripaudio = zcmds.cmds.common.stripaudio:main",
        "vid2gif = zcmds.cmds.common.vid2gif:main",
        "vid2jpg = zcmds.cmds.common.vid2jpg:main",
        "vid2mp3 = zcmds.cmds.common.vid2mp3:main",
        "vid2mp4 = zcmds.cmds.common.vid2mp4:main",
        "vid2webm = zcmds.cmds.common.vid2webm:main",
        "vidclip = zcmds.cmds.common.vidclip:main",
        "viddur = zcmds.cmds.common.viddur:main",
        "vidspeed = zcmds.cmds.common.vidspeed:main",
        "vidvol = zcmds.cmds.common.vidvol:main",
        "vidshrink = zcmds.cmds.common.vidshrink:main"
    ],
    "win32": [
        "cat = zcmds.cmds.win32.cat:main",
        "cp = zcmds.cmds.win32.cp:main",
        "du = zcmds.cmds.win32.du:main",
        "grep = zcmds.cmds.win32.grep:main",
        "home = zcmds.cmds.win32.home:main",
        "ls = zcmds.cmds.win32.ls:main",
        "mv = zcmds.cmds.win32.mv:main",
        "open = zcmds.cmds.win32.open:main",
        "rm = zcmds.cmds.win32.rm:main",
        "which = zcmds.cmds.win32.which:main",
        "git-bash = zcmds.cmds.win32.git_bash:main"
    ]
}
